#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson
version:              2.2.2.0
visibility:           public
id:                   aeson-2.2.2.0-CZIrLrIqsbVBSATKMNLvxW
key:                  aeson-2.2.2.0-CZIrLrIqsbVBSATKMNLvxW
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  3dbbf4b481be6f31341734b14d303431
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Decoding Data.Aeson.Decoding.ByteString
    Data.Aeson.Decoding.ByteString.Lazy Data.Aeson.Decoding.Text
    Data.Aeson.Decoding.Tokens Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Key Data.Aeson.KeyMap
    Data.Aeson.QQ.Simple Data.Aeson.RFC8785 Data.Aeson.TH
    Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Decoding.Conversion Data.Aeson.Decoding.Internal
    Data.Aeson.Encoding.Builder Data.Aeson.Internal.ByteString
    Data.Aeson.Internal.Functions Data.Aeson.Internal.Prelude
    Data.Aeson.Internal.Scientific Data.Aeson.Internal.Text
    Data.Aeson.Internal.TH Data.Aeson.Internal.Unescape
    Data.Aeson.Internal.UnescapeFromText Data.Aeson.Parser.Time
    Data.Aeson.Types.Class Data.Aeson.Types.FromJSON
    Data.Aeson.Types.Generic Data.Aeson.Types.Internal
    Data.Aeson.Types.ToJSON

import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-2.2.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-2.2.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-2.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson
hs-libraries:         HSaeson-2.2.2.0-CZIrLrIqsbVBSATKMNLvxW
depends:
    OneTuple-0.4.2.1-5HdCqAVnSpqofJCCnCvbT
    QuickCheck-2.15.0.1-W9Xm8Q6jpd1zU3LZ63mq1 base-4.18.2.1
    bytestring-0.11.5.3 character-ps-0.1-H07uOjD6SD1EfE7l9KfeMv
    containers-0.6.7 data-fix-0.3.4-HoZ4BCOikxlECT4rwHwkUF
    deepseq-1.4.8.1 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO exceptions-0.10.7
    generically-0.1.1-I9byc5Nil798plofO827gA ghc-prim-0.10.0
    hashable-1.4.7.0-D6t6qvvDqS783ayXdNNEFV
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    integer-conversion-0.1.1-1C1K2vxFCJxLttCTL8hFRY
    integer-logarithms-1.0.4-22LppUAaU6yAsRnhxn7Oia
    network-uri-2.6.4.2-DZsK30J0JA75RbwwKgdhQI
    primitive-0.9.1.0-94Qnzznh8Dc4Pbexl4gZ0v
    scientific-0.3.8.1-31CWcid3qo6Aj4OF43pUKd
    semialign-1.3.1.1-JnEyzZay1stz7sgOL9fAX
    strict-0.5.1-Eyx6uOpIJPsCjOhd1pfow8
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    text-2.0.2 text-iso8601-0.1.1.1-FqPsbPd39fM89N63HhumVh
    text-short-0.1.6.1-Lbois4yWyDJEmpZWFGNH8X
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3
    these-1.2.1-AU184eGvYOe87saNiEeFeU time-1.12.2
    time-compat-1.9.9-BKGzOMn1Tbs1xqTkYKCXik
    unordered-containers-0.2.20.1-170HxTRPWLJC6Js92iIt2k
    uuid-types-1.0.6-3BdVbVBlhqM1Xh9hiS7QQ6
    vector-0.13.2.0-LuonB4ieSbk1FHCVO4HoCK
    witherable-0.4.2-8NyK6nZCG5e1rMBOGt3iED

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

